errors

package
v0.4.23 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 2, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NotFound added in v0.4.0

type NotFound struct {
	// contains filtered or unexported fields
}

NotFound represents a not found error in the application.

func NewNotFound added in v0.4.0

func NewNotFound(message string, err ...error) NotFound

NewNotFound creates a new NotFound error with the provided message.

func (NotFound) Error added in v0.4.0

func (v NotFound) Error() string

Error returns the error message for NotFound.

type ServiceUnavailable

type ServiceUnavailable struct {
	// contains filtered or unexported fields
}

ServiceUnavailable represents a service unavailability error in the application.

func NewServiceUnavailable

func NewServiceUnavailable(message string, err ...error) ServiceUnavailable

NewServiceUnavailable creates a new ServiceUnavailable error with the provided message.

func (ServiceUnavailable) Error

func (su ServiceUnavailable) Error() string

Error returns the error message for ServiceUnavailable.

type Unexpected

type Unexpected struct {
	// contains filtered or unexported fields
}

Unexpected represents an unexpected error in the application.

func NewUnexpected

func NewUnexpected(message string, err ...error) Unexpected

NewUnexpected creates a new Unexpected error with the provided message.

func (Unexpected) Error

func (u Unexpected) Error() string

Error returns the error message for Unexpected.

type Validation

type Validation struct {
	// contains filtered or unexported fields
}

Validation represents a validation error in the application.

func NewValidation

func NewValidation(message string, err ...error) Validation

NewValidation creates a new Validation error with the provided message.

func (Validation) Error

func (v Validation) Error() string

Error returns the error message for Validation.

Jump to